aboutsummaryrefslogtreecommitdiffstats
path: root/tools
diff options
context:
space:
mode:
authorPascal Quantin <pascal.quantin@gmail.com>2018-01-09 23:38:47 +0100
committerAnders Broman <a.broman58@gmail.com>2018-01-10 05:31:33 +0000
commit88abff68df5fcea46e1f7f0a32d7fe8718fd67c0 (patch)
tree802e75b2a344129a51605e451e0cba45913536e7 /tools
parentfb4953a13c1ac6e5b54a347769c5f05e8fd6ab28 (diff)
NR RRC: add initial dissector based on v15.0.0
ASN.1 prose imported from the specification and heavily modified manually to workaround its poor quality. Some of them are marked with -- WS modification comment, some are not. Probably useless as-is, but it is an initial start until an updated version is available. Change-Id: I19ab6cedb6aa23c8ed57bae525ee4a3391494e32 Reviewed-on: https://code.wireshark.org/review/25235 Petri-Dish: Pascal Quantin <pascal.quantin@gmail.com> Tested-by: Petri Dish Buildbot Reviewed-by: Anders Broman <a.broman58@gmail.com>
Diffstat (limited to 'tools')
-rwxr-xr-xtools/extract_asn1_from_spec.pl4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/extract_asn1_from_spec.pl b/tools/extract_asn1_from_spec.pl
index 43db8f8748..3152b584d9 100755
--- a/tools/extract_asn1_from_spec.pl
+++ b/tools/extract_asn1_from_spec.pl
@@ -1,6 +1,6 @@
#!/usr/bin/perl
#
# This script extracts the ASN1 definition from and TS 36.331/36.355/25.331
# and generates asn files that can be processed by asn2wrs
# First download the specification from 3gpp.org as a word document and open it
# Then in "view" menu, select normal, draft or web layout (any kind that removes page header and footers)
@@ -47,7 +47,7 @@ close(INPUT_FILE);
sub extract_spec_version {
my $line;
while($line = <INPUT_FILE>){
- if($line =~ m/3GPP TS ((25|36)\.331|36\.355) V/){
+ if($line =~ m/3GPP TS ((25|36|38)\.331|36\.355) V/){
$version = $line;
return;
}
@@ -1,6 +1,6 @@
#!/usr/bin/perl
#
-# This script extracts the ASN1 definition from and TS 36.331/36.355/25.331
+# This script extracts the ASN1 definition from and TS 36.331/36.355/25.331/38.331
# and generates asn files that can be processed by asn2wrs
# First download the specification from 3gpp.org as a word document and open it